==> kdeedu-4.1.0.tar.bz2: kdeedu-4.1.0/marble/src/lib/geodata/handlers/kml/KmlPolyStyleTagHandler.cpp <==
/*
    Copyright (C) 2008 Patrick Spendrin <ps_ml@gmx.de>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include "KmlPolyStyleTagHandler.h"

#include <QtCore/QDebug>

#include "KmlElementDictionary.h"
#include "GeoDataPolyStyle.h"
#include "GeoDataParser.h"

using namespace GeoDataElementDictionary;

KML_DEFINE_TAG_HANDLER( PolyStyle )

KmlPolyStyleTagHandler::KmlPolyStyleTagHandler()
    : GeoTagHandler()
{
}

KmlPolyStyleTagHandler::~KmlPolyStyleTagHandler()
{
}

GeoNode* KmlPolyStyleTagHandler::parse( GeoParser& parser ) const
{
    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_PolyStyle ) );

    GeoStackItem parentItem = parser.parentElement();
    
    GeoDataPolyStyle* style = 0;
    
    if ( parentItem.represents( kmlTag_Style ) ) {
        style = new GeoDataPolyStyle();
#ifdef DEBUG_TAGS
        qDebug() << "Parsed <" << kmlTag_PolyStyle << "> containing: " << style
                 << " parent item name: " << parentItem.qualifiedName().first;
#endif // DEBUG_TAGS
    }
    return style;
}

==> kdeedu-4.2.3.tar.bz2: kdeedu-4.2.3/marble/src/lib/geodata/handlers/kml/KmlPolyStyleTagHandler.cpp <==
/*
    Copyright (C) 2008 Patrick Spendrin <ps_ml@gmx.de>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include "KmlPolyStyleTagHandler.h"

#include <QtCore/QDebug>

#include "KmlElementDictionary.h"
#include "GeoDataStyle.h"
#include "GeoDataPolyStyle.h"
#include "GeoDataParser.h"

namespace Marble
{
namespace kml
{
KML_DEFINE_TAG_HANDLER( PolyStyle )

GeoNode* KmlPolyStyleTagHandler::parse( GeoParser& parser ) const
{
    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_PolyStyle ) );

    GeoStackItem parentItem = parser.parentElement();
    
    GeoDataPolyStyle* style = 0;
    
    if ( parentItem.represents( kmlTag_Style ) ) {
        style = new GeoDataPolyStyle();
        parentItem.nodeAs<GeoDataStyle>()->setPolyStyle( style );
#ifdef DEBUG_TAGS
        qDebug() << "Parsed <" << kmlTag_PolyStyle << "> containing: " << style
                 << " parent item name: " << parentItem.qualifiedName().first;
#endif // DEBUG_TAGS
    }
    return style;
}

}
}
